pub struct NodeInteractiveRegion {
pub key: String,
pub slot_kind: Option<NodeSurfaceSlotKind>,
pub rect: CanvasRect,
pub label: Option<String>,
pub z_index: i32,
}Expand description
Named hit-test or event region produced by a rich renderer.
The rect is node-local and relative to the node’s top-left corner.
Fields
key: Stringslot_kind: Option<NodeSurfaceSlotKind>rect: CanvasRectlabel: Option<String>z_index: i32Trait Implementations
Sourceimpl Clone for NodeInteractiveRegion
impl Clone for NodeInteractiveRegion
Sourcefn clone(&self) -> NodeInteractiveRegion
fn clone(&self) -> NodeInteractiveRegion
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for NodeInteractiveRegion
impl Debug for NodeInteractiveRegion
Sourceimpl PartialEq for NodeInteractiveRegion
impl PartialEq for NodeInteractiveRegion
Sourcefn eq(&self, other: &NodeInteractiveRegion) -> bool
fn eq(&self, other: &NodeInteractiveRegion) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for NodeInteractiveRegion